if Dominos then
local bar = _G[...]
local modName = ...
local L

local function AddLayoutPanel(menu)
	local panel = menu:NewPanel(L.Layout)
	panel:NewSlider('Scroll Speed', 1, 250, 1,
		function(self) --Getter
			self:SetValue(self:GetParent().owner.sets.scrollStep)
		end,
		function(self) --Setter
			self:GetParent().owner.sets.scrollStep = self:GetValue()
		end
	)
	
	panel.opacitySlider = panel:NewOpacitySlider()
	panel.fadeSlider = panel:NewFadeSlider()
	panel.paddingSlider = panel:NewPaddingSlider()
	panel:NewSlider('Height', 250, 500, 1,
		function(self) --Getter
			self:SetValue(self:GetParent().owner.sets.height)
		end,
		function(self) --Setter
			self:GetParent().owner.sets.height = self:GetValue()
			self:GetParent().owner:Layout()
		end
	)
--[[	panel:NewSlider('Width', 75, 250, 1,
		function(self) --Getter
			self:SetValue(self:GetParent().owner.sets.width)
		end,
		function(self) --Setter
			self:GetParent().owner.sets.width = self:GetValue()
			self:GetParent().owner:Layout()
		end
	)--]]
	

	panel.scaleSlider = panel:NewScaleSlider()
	return panel
end

local function AddShowState(self)
	local p = self:NewPanel(L.ShowStates)
	p.height = 56
	local editBox = CreateFrame('EditBox', p:GetName() .. 'StateText', p, 'InputBoxTemplate')
	editBox:SetWidth(148) editBox:SetHeight(20)
	editBox:SetPoint('TOPLEFT', 12, -10)
	editBox:SetAutoFocus(false)
	editBox:SetScript('OnShow', function(self)
		self:SetText(self:GetParent().owner:GetShowStates() or '')
	end)
	editBox:SetScript('OnEnterPressed', function(self)
		local text = self:GetText()
		self:GetParent().owner:SetShowStates(text ~= '' and text or nil)
		self:ClearFocus()
	end)
	editBox:SetScript('OnEditFocusLost', function(self) self:HighlightText(0, 0) end)
	editBox:SetScript('OnEditFocusGained', function(self) self:HighlightText() end)
	local set = CreateFrame('Button', p:GetName() .. 'Set', p, 'UIPanelButtonTemplate')
	set:SetWidth(30) set:SetHeight(20)
	set:SetText(L.Set)
	set:SetScript('OnClick', function(self)
		local text = editBox:GetText()
		self:GetParent().owner:SetShowStates(text ~= '' and text or nil)
		editBox:SetText(self:GetParent().owner:GetShowStates() or '')
		editBox:ClearFocus()
	end)
	set:SetPoint('BOTTOMRIGHT', -8, 2)
	return p
end

local function AddAdvancedPanel(menu)
	local panel = menu:NewPanel(L.Advanced)
	panel:NewClickThroughCheckbox()
	panel:NewShowInOverrideUICheckbox()
	panel:NewShowInPetBattleUICheckbox()
	return panel
end

function bar:CreateMenu()
	local menu = Dominos:NewMenu(self.id)
	L = LibStub('AceLocale-3.0'):GetLocale('Dominos-Config')

	AddLayoutPanel(menu)

	if self.components then
		for i, b in pairs(self.components) do
			if b.CreateMenu and bar.Menu then
				b:CreateMenu(menu)
			end
		end
	end

	AddAdvancedPanel(menu)
	return menu
end


local menu, config
function bar:ShowMenu()
	if not bar.master:IsConfigAddonEnabled() then return end
	config = config or LoadAddOn('Dominos_Config')
	L = L or LibStub('AceLocale-3.0'):GetLocale('Dominos-Config')
	bar.menu = bar.menu or self:CreateMenu()

	local menu = bar.menu
	menu:Hide()
	menu:SetOwner(self)
	menu:ShowPanel(L.Layout)
	menu:Show()
end
elseif Bartender then
--[[
	Copyright (c) 2009-2015, Hendrik "Nevcairiel" Leppkes < h.leppkes at gmail dot com >
	All rights reserved.
]]
local _, Bartender4 = ...
local L = LibStub("AceLocale-3.0"):GetLocale("Bartender4")

local ObjectiveBarMod = Bartender4:GetModule("ObjectiveBar")

-- fetch upvalues
local Bar = Bartender4.Bar.prototype

local barregistry = Bartender4.Bar.barregistry


	-- maps option keys to function names
	local optionMap = {
		alpha = "ConfigAlpha",
		scale = "ConfigScale",
		fadeout = "FadeOut",
		fadeoutalpha = "FadeOutAlpha",
		fadeoutdelay = "FadeOutDelay",
		clickthrough = "ClickThrough",
	}

	-- retrieves a valid bar object from the barregistry table
	local function getBar(id)
		local bar = barregistry[tostring(id)]
		print(bar:GetName())
		assert(bar, ("Invalid bar id in options table. (%s)"):format(id))
		return bar
	end

	-- calls a function on the bar
	local function callFunc(bar, type, option, ...)
		local func = type .. (optionMap[option] or option)
		assert(bar[func], ("Invalid get/set function %s in bar %s."):format(func, bar.id))
		return bar[func](bar, ...)
	end

	-- universal function to get a option
	local function optGetter(info)
		local bar = getBar(info[2])
		local option = info[#info]
		return callFunc(bar, "Get", option)
	end

	-- universal function to set a option
	local function optSetter(info, ...)
		local bar = getBar(info[2])
		local option = info[#info]
		return callFunc(bar, "Set", option, ...)
	end

function ObjectiveBarMod:SetupOptions()
	if not self.options then
		self.optionobject = Bar:GetOptionObject()
		local otbl_general = {
			enabled = {
				type = "toggle",
				order = 1,
				name = "Enabled",
				desc = "Enable the Objective Bar",
				get = function() return self.db.profile.enabled end,
				set = "ToggleModule",
				handler = self,
			},
		}
		self.optionobject:AddElementGroup("general", otbl_general)
		
		self.disabledoptions = {
			general = {
				type = "group",
				name = "General Settings",
				cmdInline = true,
				order = 1,
				args = {
					enabled = enabled,
				}
			}
		}
		self.options = {
			order = 30,
			type = "group",
			name = "Objective Bar",
			desc = "Configure the Objective Bar",
			childGroups = "tab",
		}

		Bartender4:RegisterBarOptions("ObjectiveBar", self.options)
	end
	self.options.args = self:IsEnabled() and self.optionobject.table or self.disabledoptions
end

end